pub struct PostPythPullOracleUpdateAtomic {
pub keeper: Pubkey,
pub pyth_solana_receiver: Pubkey,
pub guardian_set: Pubkey,
pub price_feed: Pubkey,
}Expand description
Generated client accounts for PostPythPullOracleUpdateAtomic.
Fields
keeper: Pubkeypyth_solana_receiver: Pubkeyguardian_set: Pubkeyprice_feed: PubkeyTrait Implementations
Sourceimpl BorshSerialize for PostPythPullOracleUpdateAtomicwhere
Pubkey: BorshSerialize,
impl BorshSerialize for PostPythPullOracleUpdateAtomicwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for PostPythPullOracleUpdateAtomic
impl ToAccountMetas for PostPythPullOracleUpdateAtomic
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for PostPythPullOracleUpdateAtomic
impl RefUnwindSafe for PostPythPullOracleUpdateAtomic
impl Send for PostPythPullOracleUpdateAtomic
impl Sync for PostPythPullOracleUpdateAtomic
impl Unpin for PostPythPullOracleUpdateAtomic
impl UnwindSafe for PostPythPullOracleUpdateAtomic