pub struct UpdatePythPullOracle {
pub keeper: Pubkey,
pub pyth_solana_receiver: Pubkey,
pub encoded_vaa: Pubkey,
pub price_feed: Pubkey,
}Expand description
Generated client accounts for UpdatePythPullOracle.
Fields
keeper: Pubkeypyth_solana_receiver: Pubkeyencoded_vaa: Pubkeyprice_feed: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdatePythPullOraclewhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdatePythPullOraclewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdatePythPullOracle
impl ToAccountMetas for UpdatePythPullOracle
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdatePythPullOracle
impl RefUnwindSafe for UpdatePythPullOracle
impl Send for UpdatePythPullOracle
impl Sync for UpdatePythPullOracle
impl Unpin for UpdatePythPullOracle
impl UnwindSafe for UpdatePythPullOracle