pub struct FillPerpOrder {
pub _order_id: Option<u32>,
pub _maker_order_id: Option<u32>,
}Expand description
Instruction.
Fields
_order_id: Option<u32>_maker_order_id: Option<u32>Trait Implementations
Sourceimpl BorshDeserialize for FillPerpOrder
impl BorshDeserialize for FillPerpOrder
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for FillPerpOrder
impl BorshSerialize for FillPerpOrder
Sourceimpl Discriminator for FillPerpOrder
impl Discriminator for FillPerpOrder
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for FillPerpOrder
impl InstructionData for FillPerpOrder