pub struct InitUserFuel {
pub _fuel_boost_deposits: Option<u32>,
pub _fuel_boost_borrows: Option<u32>,
pub _fuel_boost_taker: Option<u32>,
pub _fuel_boost_maker: Option<u32>,
pub _fuel_boost_insurance: Option<u32>,
}Expand description
Instruction.
Fields
_fuel_boost_deposits: Option<u32>_fuel_boost_borrows: Option<u32>_fuel_boost_taker: Option<u32>_fuel_boost_maker: Option<u32>_fuel_boost_insurance: Option<u32>Trait Implementations
Sourceimpl BorshDeserialize for InitUserFuel
impl BorshDeserialize for InitUserFuel
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for InitUserFuel
impl BorshSerialize for InitUserFuel
Sourceimpl Discriminator for InitUserFuel
impl Discriminator for InitUserFuel
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for InitUserFuel
impl InstructionData for InitUserFuel