pub struct TriggerOrder {
pub _order_id: u32,
}Expand description
Instruction.
Fields
_order_id: u32Trait Implementations
Sourceimpl BorshDeserialize for TriggerOrderwhere
u32: BorshDeserialize,
impl BorshDeserialize for TriggerOrderwhere
u32: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TriggerOrderwhere
u32: BorshSerialize,
impl BorshSerialize for TriggerOrderwhere
u32: BorshSerialize,
Sourceimpl Discriminator for TriggerOrder
impl Discriminator for TriggerOrder
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for TriggerOrder
impl InstructionData for TriggerOrder