pub struct UpdateUserDelegate {
pub _sub_account_id: u16,
pub _delegate: Pubkey,
}Expand description
Instruction.
Fields
_sub_account_id: u16_delegate: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for UpdateUserDelegate
impl BorshDeserialize for UpdateUserDelegate
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateUserDelegate
impl BorshSerialize for UpdateUserDelegate
Sourceimpl Discriminator for UpdateUserDelegate
impl Discriminator for UpdateUserDelegate
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for UpdateUserDelegate
impl InstructionData for UpdateUserDelegate