pub struct ProtocolIfSharesTransferConfig {
pub whitelisted_signers: [Pubkey; 4],
pub max_transfer_per_epoch: u128,
pub current_epoch_transfer: u128,
pub next_epoch_ts: i64,
pub padding: [u128; 8],
}Expand description
Account: ProtocolIfSharesTransferConfig
Fields
whitelisted_signers: [Pubkey; 4]max_transfer_per_epoch: u128current_epoch_transfer: u128next_epoch_ts: i64padding: [u128; 8]Trait Implementations
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourcefn clone(&self) -> ProtocolIfSharesTransferConfig
fn clone(&self) -> ProtocolIfSharesTransferConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourcefn default() -> ProtocolIfSharesTransferConfig
fn default() -> ProtocolIfSharesTransferConfig
Returns the “default value” for a type. Read more
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]