pub struct User {Show 29 fields
pub authority: Pubkey,
pub delegate: Pubkey,
pub name: [u8; 32],
pub spot_positions: [SpotPosition; 8],
pub perp_positions: [PerpPosition; 8],
pub orders: [Order; 32],
pub last_add_perp_lp_shares_ts: i64,
pub total_deposits: u64,
pub total_withdraws: u64,
pub total_social_loss: u64,
pub settled_perp_pnl: i64,
pub cumulative_spot_fees: i64,
pub cumulative_perp_funding: i64,
pub liquidation_margin_freed: u64,
pub last_active_slot: u64,
pub next_order_id: u32,
pub max_margin_ratio: u32,
pub next_liquidation_id: u16,
pub sub_account_id: u16,
pub status: u8,
pub is_margin_trading_enabled: bool,
pub idle: bool,
pub open_orders: u8,
pub has_open_order: bool,
pub open_auctions: u8,
pub has_open_auction: bool,
pub padding1: [u8; 5],
pub last_fuel_bonus_update_ts: u32,
pub padding: [u8; 12],
}Expand description
Account: User
Fields
delegate: Pubkeyname: [u8; 32]spot_positions: [SpotPosition; 8]perp_positions: [PerpPosition; 8]orders: [Order; 32]total_deposits: u64total_withdraws: u64settled_perp_pnl: i64cumulative_spot_fees: i64cumulative_perp_funding: i64liquidation_margin_freed: u64last_active_slot: u64next_order_id: u32max_margin_ratio: u32next_liquidation_id: u16sub_account_id: u16status: u8is_margin_trading_enabled: boolidle: boolopen_orders: u8has_open_order: boolopen_auctions: u8has_open_auction: boolpadding1: [u8; 5]last_fuel_bonus_update_ts: u32padding: [u8; 12]Trait Implementations
Sourceimpl AccountDeserialize for User
impl AccountDeserialize for User
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for User
impl AccountSerialize for User
Sourceimpl BorshDeserialize for Userwhere
Pubkey: BorshDeserialize,
[u8; 32]: BorshDeserialize,
[SpotPosition; 8]: BorshDeserialize,
[PerpPosition; 8]: BorshDeserialize,
[Order; 32]: BorshDeserialize,
i64: BorshDeserialize,
u64: BorshDeserialize,
u32: BorshDeserialize,
u16: BorshDeserialize,
u8: BorshDeserialize,
bool: BorshDeserialize,
[u8; 5]: BorshDeserialize,
[u8; 12]: BorshDeserialize,
impl BorshDeserialize for Userwhere
Pubkey: BorshDeserialize,
[u8; 32]: BorshDeserialize,
[SpotPosition; 8]: BorshDeserialize,
[PerpPosition; 8]: BorshDeserialize,
[Order; 32]: BorshDeserialize,
i64: BorshDeserialize,
u64: BorshDeserialize,
u32: BorshDeserialize,
u16: BorshDeserialize,
u8: BorshDeserialize,
bool: BorshDeserialize,
[u8; 5]: BorshDeserialize,
[u8; 12]: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Userwhere
Pubkey: BorshSerialize,
[u8; 32]: BorshSerialize,
[SpotPosition; 8]: BorshSerialize,
[PerpPosition; 8]: BorshSerialize,
[Order; 32]: BorshSerialize,
i64: BorshSerialize,
u64: BorshSerialize,
u32: BorshSerialize,
u16: BorshSerialize,
u8: BorshSerialize,
bool: BorshSerialize,
[u8; 5]: BorshSerialize,
[u8; 12]: BorshSerialize,
impl BorshSerialize for Userwhere
Pubkey: BorshSerialize,
[u8; 32]: BorshSerialize,
[SpotPosition; 8]: BorshSerialize,
[PerpPosition; 8]: BorshSerialize,
[Order; 32]: BorshSerialize,
i64: BorshSerialize,
u64: BorshSerialize,
u32: BorshSerialize,
u16: BorshSerialize,
u8: BorshSerialize,
bool: BorshSerialize,
[u8; 5]: BorshSerialize,
[u8; 12]: BorshSerialize,
Sourceimpl Discriminator for User
impl Discriminator for User
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
impl Copy for User