pub struct UserStats {Show 25 fields
pub authority: Pubkey,
pub referrer: Pubkey,
pub fees: UserFees,
pub next_epoch_ts: i64,
pub maker_volume30d: u64,
pub taker_volume30d: u64,
pub filler_volume30d: u64,
pub last_maker_volume30d_ts: i64,
pub last_taker_volume30d_ts: i64,
pub last_filler_volume30d_ts: i64,
pub if_staked_quote_asset_amount: u64,
pub number_of_sub_accounts: u16,
pub number_of_sub_accounts_created: u16,
pub is_referrer: bool,
pub disable_update_perp_bid_ask_twap: bool,
pub padding1: [u8; 2],
pub fuel_insurance: u32,
pub fuel_deposits: u32,
pub fuel_borrows: u32,
pub fuel_positions: u32,
pub fuel_taker: u32,
pub fuel_maker: u32,
pub if_staked_gov_token_amount: u64,
pub last_fuel_if_bonus_update_ts: u32,
pub padding: [u8; 12],
}Expand description
Account: UserStats
Fields
referrer: Pubkeyfees: UserFeesnext_epoch_ts: i64maker_volume30d: u64taker_volume30d: u64filler_volume30d: u64last_maker_volume30d_ts: i64last_taker_volume30d_ts: i64last_filler_volume30d_ts: i64if_staked_quote_asset_amount: u64number_of_sub_accounts: u16number_of_sub_accounts_created: u16is_referrer: booldisable_update_perp_bid_ask_twap: boolpadding1: [u8; 2]fuel_insurance: u32fuel_deposits: u32fuel_borrows: u32fuel_positions: u32fuel_taker: u32fuel_maker: u32if_staked_gov_token_amount: u64last_fuel_if_bonus_update_ts: u32padding: [u8; 12]Trait Implementations
Sourceimpl AccountDeserialize for UserStats
impl AccountDeserialize for UserStats
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for UserStats
impl AccountSerialize for UserStats
Sourceimpl BorshDeserialize for UserStatswhere
Pubkey: BorshDeserialize,
UserFees: BorshDeserialize,
i64: BorshDeserialize,
u64: BorshDeserialize,
u16: BorshDeserialize,
bool: BorshDeserialize,
[u8; 2]: BorshDeserialize,
u32: BorshDeserialize,
[u8; 12]: BorshDeserialize,
impl BorshDeserialize for UserStatswhere
Pubkey: BorshDeserialize,
UserFees: BorshDeserialize,
i64: BorshDeserialize,
u64: BorshDeserialize,
u16: BorshDeserialize,
bool: BorshDeserialize,
[u8; 2]: BorshDeserialize,
u32: BorshDeserialize,
[u8; 12]: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UserStatswhere
Pubkey: BorshSerialize,
UserFees: BorshSerialize,
i64: BorshSerialize,
u64: BorshSerialize,
u16: BorshSerialize,
bool: BorshSerialize,
[u8; 2]: BorshSerialize,
u32: BorshSerialize,
[u8; 12]: BorshSerialize,
impl BorshSerialize for UserStatswhere
Pubkey: BorshSerialize,
UserFees: BorshSerialize,
i64: BorshSerialize,
u64: BorshSerialize,
u16: BorshSerialize,
bool: BorshSerialize,
[u8; 2]: BorshSerialize,
u32: BorshSerialize,
[u8; 12]: BorshSerialize,
Sourceimpl Discriminator for UserStats
impl Discriminator for UserStats
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
impl Copy for UserStats